@@ -1,4 +1,4 @@
-__all__ = ('UploadFilePoint', 'UserFileObjectPoint', 'UserFilePoint')
+__all__ = ('UploadFilePoint', 'UserFileObjectPoint', 'UserFilePoint', 'UploadPassportPoint')
 
 from django.core.validators import RegexValidator
 
@@ -12,6 +12,10 @@ class UploadFileResponseContract(Contract):
     name = serializers.CharField(max_length=64, validators=(alphanumeric,))
 
 
+class UploadPassportResponseContract(UploadFileResponseContract):
+    ...
+
+
 class UserFileReadContract(UploadFileResponseContract):
     id = serializers.IntegerField(min_value=1)
     public_url = serializers.URLField(allow_null=True)
@@ -30,6 +34,12 @@ class UploadFileID(ID):
     _view_set = 'upload_file/'
 
 
+class UploadPassportID(ID):
+    _service = SERVICE
+    _app = SERVICE
+    _view_set = 'upload_passport/'
+
+
 class UserFileObjectPoint(RetrievePointMixin, ContractObjectPoint):
     _cache_enabled = False
     _point_id = UserFileID()
@@ -42,6 +52,12 @@ class UploadFilePoint(UploadFilePointMixin, ResponseMixin, ContractPoint):
     _read_contract = None
 
 
+class UploadPassportPoint(UploadFilePointMixin, ResponseMixin, ContractPoint):
+    _point_id = UploadPassportID()
+    _response_contract = UploadPassportResponseContract
+    _read_contract = None
+
+
 class UserFilePoint(ListPointMixin, ContractPoint):
     _cache_enabled = False
     _point_id = UserFileID()
